finish method
void
finish()
Marks the tutorial as finished from any step.
After calling finish, the controller enters a finished state and subsequent calls to advance or skip will return false without changing the current step index.
Implementation
void finish() {
if (_isFinished) {
return;
}
_lastCompletionReason = TutorialCompletionReason.finished;
_isFinished = true;
_isFinishedNotifier.value = true;
}